@@ -4,31 +4,19 @@
  */
 
 #pragma once
-#include <aws/iam/IAM_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/iam/IAM_EXPORTS.h>
 
-namespace Aws
-{
-namespace IAM
-{
-namespace Model
-{
-  enum class EntityType
-  {
-    NOT_SET,
-    User,
-    Role,
-    Group,
-    LocalManagedPolicy,
-    AWSManagedPolicy
-  };
+namespace Aws {
+namespace IAM {
+namespace Model {
+enum class EntityType { NOT_SET, User, Role, Group, LocalManagedPolicy, AWSManagedPolicy };
 
-namespace EntityTypeMapper
-{
+namespace EntityTypeMapper {
 AWS_IAM_API EntityType GetEntityTypeForName(const Aws::String& name);
 
 AWS_IAM_API Aws::String GetNameForEntityType(EntityType value);
-} // namespace EntityTypeMapper
-} // namespace Model
-} // namespace IAM
-} // namespace Aws
+}  // namespace EntityTypeMapper
+}  // namespace Model
+}  // namespace IAM
+}  // namespace Aws
