@@ -50,9 +50,12 @@ enum class STSErrors {
   INVALID_IDENTITY_TOKEN,
   I_D_P_COMMUNICATION_ERROR,
   I_D_P_REJECTED_CLAIM,
+  J_W_T_PAYLOAD_SIZE_EXCEEDED,
   MALFORMED_POLICY_DOCUMENT,
+  OUTBOUND_WEB_IDENTITY_FEDERATION_DISABLED,
   PACKED_POLICY_TOO_LARGE,
-  REGION_DISABLED
+  REGION_DISABLED,
+  SESSION_DURATION_ESCALATION
 };
 
 class AWS_STS_API STSError : public Aws::Client::AWSError<STSErrors> {
